@@ -26,17 +26,13 @@ Tree::RB::XS::Node
 
 =head1 DESCRIPTION
 
-Node objects represent an internal node of the Red/Black tree.  Tree nodes exists as lightweight
-C structs until you access it from Perl, at which time it inflates to become a blessed hashref
+Node objects represent an internal node of the Red/Black tree.  A tree node exists as lightweight
+C struct until you access it from Perl, at which time it inflates to become a blessed hashref
 object.  This object does not hold a strong reference to the tree; if the tree goes out of scope,
-the nodes remain but no longer have a relation to eachother.
+the node object remains but no longer has a relation to other nodes.
 
 Nodes can only be created by a tree, and cannot be re-inserted once pruned.
 
-=head1 NAME
-
-Tree::RB::XS::Node
-
 =head1 ATTRIBUTES
 
 =head2 key
@@ -127,7 +123,8 @@ is no longer in the tree.
 =head2 prune
 
 Remove this single node from the tree.  The node will still have its key and value,
-but all attributes linking to other nodes will become C<undef>.
+but all attributes linking to other nodes will become C<undef>, and L</count> becomes
+zero.
 
 =head2 strip
 
@@ -157,7 +154,7 @@ Shortcut for C<< $node->tree->iter_new_to_old($node) >>.
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 AUTHOR
 
